@title BookBot
@param z zoom index
@default z 2
@param f focus index
@default f 360
@param a aperture index
@default a 9
@param t shutter index
@default t 20

rem Function call sets initial zoom, focus, etc.

gosub "initialization"

rem 1st (setup) loop used for manual tweaking of zoom, focus & shutter speed
rem -L/R for focus, up/down for shutter speed, zoom dial for zoom
rem -Shutter half-press to autofocus, SET to skip
rem -Times out and proceeds to 2nd (main) loop after 10 seconds

do
  print "f=";f,"z=";z,"tv=";t
  print "press [SET] to begin"
  print "(10 second timeout)"
  q=1
  wait_click 10000
  is_key k "left"
    if k=1 then gosub "k_left"
  is_key k "right"
    if k=1 then gosub "k_right"
  is_key k "up"
    if k=1 then gosub "k_up"
  is_key k "down"
    if k=1 then gosub "k_down"
  is_key k "zoom_in"
    if k=1 then gosub "k_zoom_in"
  is_key k "zoom_out"
    if k=1 then gosub "k_zoom_out"
  is_key k "shoot_half"
    if k=1 then gosub "k_focus"
  is_key k "set"
    if k=1 then q=1
  gosub "check_camera_mode"
  cls
until q=1
goto "loop"
end


rem 2nd (main) loop waits for signal from USB port
rem -Short (~200ms) USB signal is assumed to be remote and triggers shutter
rem -Long USB signal is assumed to be USB data and disables remote,
rem  prompting camera to switch to playback mode automatically
rem -When USB data signal stops, initialization routine is triggered
rem  and camera resumes waiting for USB signal

:loop
  print "waiting for USB signal"
  do
    if get_mode then
      gosub "initialization"
      print "waiting for USB signal"
    endif
  until is_pressed "remote"
  print "signal received"
  i=0
  p=0
  while i<30 do
    if is_pressed "remote" then
      i=i+1
    else
      p=i
      i=30
    endif
  wend
  if p=0 then
    print "switching to USB data"
    set_config_value 121 0
  else
    print "shutter triggered"
    click "shoot_full"
    sleep 3000
  endif
  cls
goto "loop"




rem Initialization routine sets focus, shutter speed, etc.

:initialization

rem Checks for playback mode before proceeding, sets to record mode if needed

if get_mode then
  print "playback mode detected"
  while get_mode do
    set_record(1)
    sleep 50
  wend
  print "switched to record mode"
else
  print "in record mode"
endif

rem Ensures CHDK USB remote flag is switched on

get_config_value 121 x y
if y = 0 then
  print "turning on USB remote"
  set_config_value 121 1
else
  print "USB remote is on"
endif

rem Checks mode dial and prompts to switch to Manual
rem Upon mode switch, shutter half-press clears set/func menu

get_prop 49 x
y=x
while not x=-32767 do
  cls
  get_prop 49 x
  print "set mode dial to M"
  sleep 100
wend
if not y=-32767 then
  click "shoot_half"
  sleep 500
else
  print "dial is at M mode"
endif

rem Simulates key-presses to switch to manual focus
rem can get caught in a loop if set/func menu is up

get_prop 6 x
while not x=4 do
  click "left"
  sleep 200
  click "left"
  sleep 100
  click "set"
  sleep 200
  get_prop 6 x
wend
print "manual focus set"
sleep 100

rem Sets various shooting parameters specific to BookBot application

print "setting iso av tv"
set_iso 1
set_av a
set_tv t
sleep 100
print "setting zoom",z
set_zoom z
sleep 1000
print "setting focus",f
set_focus f
sleep 1000
get_av a
get_user_tv_id t
get_zoom z
get_focus f

rem Shutter half-press refreshes camera UI shooting parameter display

click "shoot_half"
sleep 1000
cls
return




rem Function for periodically checking whether camera is in record mode
rem switches to record mode and runs initialization routine if necessary

:check_camera_mode
if get_mode then b=1 else b=0
while get_mode do
  set_record(1)
  sleep(50)
wend
if b then gosub "initialization"
return




rem Key-press subroutines used during 1st setup loop adjust focus, zoom etc.

:k_left
print "focus-"
f=f-25
set_focus f
sleep 50
get_focus f
q=0
return


:k_right
print "focus+"
f=f+25
set_focus f
sleep 50
get_focus f
q=0
return


:k_up
print "tv+"
t=t+1
set_tv t
sleep 50
get_user_tv_id t
q=0
return


:k_down
print "tv-"
t=t-1
set_tv t
sleep 50
get_user_tv_id t
q=0
return


:k_zoom_in
print "zoom+"
z=z+1
set_zoom z
sleep 50
get_zoom z
q=0
return


:k_zoom_out
print "zoom-"
z=z-1
set_zoom z
sleep 50
get_zoom z
q=0
return




rem During 1st setup loop, shutter half-press triggers autofocus

:k_focus

rem Switch to Normal focus mode

get_prop 6 x
while not x=0 do
  click "left"
  sleep 200
  click "left"
  sleep 100
  click "set"
  sleep 200
  get_prop 6 x
wend
print "autofocusing"
sleep 100
set_aflock 0
press "shoot_half"
sleep 1000
get_focus f
release "shoot_half"
sleep 1000

rem Switches back to Manual focus mode

while not x=4 do
  click "left"
  sleep 200
  click "left"
  sleep 100
  click "set"
  sleep 200
  get_prop 6 x
wend
print "manual focus set"
sleep 1000
q=0
return
